import{j as s,b3 as l,d as a}from"./index-lOezWVmi.js";const c=({children:n,title:i,docPath:e})=>s.jsxs("div",{className:"help-link",children:[n,s.jsx(l,{docPath:e,title:i,className:"help-link-doc-link",children:s.jsx(a.Icon,{name:"information",className:"help-link-icon"})})]});export{c as H};
