import{cU as o,g as a,j as e,R as s}from"./index-lOezWVmi.js";const n=({pool:t})=>{const u=o(t.driver),{data:l=[]}=a();return e.jsx("div",{children:u?l.map(r=>e.jsx("div",{className:"clustered-resource-link",children:e.jsx(s,{type:"cluster-member",value:r.server_name,to:`/ui/cluster/member/${encodeURIComponent(r.server_name)}`})},r.server_name)):e.jsx(s,{to:"/ui/cluster/members",type:"cluster-group",value:"Cluster wide"})})};export{n as S};
