import{u,z as a,q as s}from"./index-lOezWVmi.js";import{a as o,b as c}from"./network-acls-B9tLpGS2.js";const i=(e,r)=>{const{isFineGrained:n}=u();return a({queryKey:[s.projects,e,s.networkAcls],queryFn:async()=>o(e,n),enabled:n!==null})},A=(e,r,n)=>{const{isFineGrained:t}=u();return a({queryKey:[s.projects,r,s.networkAcls,e],queryFn:async()=>c(e,r,t),enabled:t!==null})};export{i as a,A as u};
