import{u as n,ai as s}from"./index-lOezWVmi.js";const P=()=>{const{isFineGrained:a}=n();return{canCreateImageAliases:e=>s(a,"can_create_image_aliases",e==null?void 0:e.access_entitlements),canCreateImages:e=>s(a,"can_create_images",e==null?void 0:e.access_entitlements),canCreateInstances:e=>s(a,"can_create_instances",e==null?void 0:e.access_entitlements),canCreateNetworks:e=>s(a,"can_create_networks",e==null?void 0:e.access_entitlements),canCreateNetworkAcls:e=>s(a,"can_create_network_acls",e==null?void 0:e.access_entitlements),canCreateProfiles:e=>s(a,"can_create_profiles",e==null?void 0:e.access_entitlements),canCreateStorageVolumes:e=>s(a,"can_create_storage_volumes",e==null?void 0:e.access_entitlements),canCreateStorageBuckets:e=>s(a,"can_create_storage_buckets",e==null?void 0:e.access_entitlements),canDeleteProject:e=>s(a,"can_delete",e==null?void 0:e.access_entitlements),canEditProject:e=>s(a,"can_edit",e==null?void 0:e.access_entitlements)}};export{P as u};
