import{u as a,j as t,d as i,N as o}from"./index-lOezWVmi.js";const u=({outlet:e})=>{const{isAuthenticated:s,isAuthLoading:r}=a();return r?t.jsx(i.Spinner,{className:"u-loader",text:"Loading...",isMainComponent:!0}):s?e:t.jsx(o,{to:"/ui/login",replace:!0})};export{u as default};
