import{u as o,z as a,g as l,q as n}from"./index-lOezWVmi.js";import{h as y,f as m,i,j as b}from"./networks-C9MSk_NH.js";const h=(e,s,r)=>{const{isFineGrained:u}=o(),t=[n.projects,e,n.networks];return a({queryKey:t,queryFn:async()=>y(e,u,s),enabled:(r??!0)&&u!==null})},k=(e,s,r,u)=>{const{isFineGrained:t}=o(),c=[n.projects,s,n.networks,e];return r&&(c.push(n.members),c.push(r)),a({queryKey:c,queryFn:async()=>m(e,s,t,r),enabled:t!==null})},q=e=>{const{isFineGrained:s}=o(),{data:r=[]}=l();return a({queryKey:[n.networks,e,n.cluster],queryFn:async()=>i(e,r,s),enabled:s!==null&&r.length>0})},w=(e,s,r)=>{const{isFineGrained:u}=o(),{data:t=[]}=l();return a({queryKey:[n.projects,s,n.networks,e,n.cluster],queryFn:async()=>b(e,s,t,u),enabled:(r??!0)&&u!==null&&t.length>0})};export{w as a,h as b,q as c,k as u};
