import{Y as a}from"./index-lOezWVmi.js";const i=(n,e,t)=>["deduplicate","A bucket with this name already exists",async(s,o)=>{const r=(o==null?void 0:o.parent).pool;return t&&s===t||a(s,n,e,`storage-pools/${encodeURIComponent(r)}/buckets`)}],u=(n,e,t,s)=>["deduplicate","A key with this name already exists",async o=>s&&o===s||a(o,n,t,`storage-pools/${encodeURIComponent(e.pool)}/buckets/${encodeURIComponent(e.name)}/keys`)],m=(n,e,t)=>`/ui/project/${encodeURIComponent(t)}/storage/pool/${encodeURIComponent(e)}/bucket/${encodeURIComponent(n)}`;export{u as a,m as g,i as t};
