import{k as i,an as p,j as a,d as o}from"./index-lOezWVmi.js";import{u as m}from"./projects-DygTcZJV.js";const l=({image:s,projectName:e})=>{const c=i(),{canCreateInstances:t}=m(),{data:n}=p(e),r=()=>{c(`/ui/project/${encodeURIComponent(e)}/instances/create`,{state:{selectedImage:s,cancelLocation:window.location.pathname}})};return a.jsx(o.Button,{appearance:"base",onClick:r,type:"button",title:t(n)?"Create instance":"You do not have permission to create instances",hasIcon:!0,disabled:!t(n),children:a.jsx(o.Icon,{name:"play"})})};export{l as C};
