import{d as r,j as o}from"./index-lOezWVmi.js";const l=({children:s,className:e})=>{const t=r.useNotify();return o.jsx(r.ScrollableContainer,{dependencies:[t.notification],belowIds:["status-bar","form-footer"],className:e,children:s})},c=(s,e)=>Object.fromEntries(Object.entries(s).filter(([t])=>!e.has(t)&&!t.startsWith("cloud-init.ssh-keys."))),d=(s,e)=>{const t=e==null?void 0:e.find(n=>n.value===s);return t!=null&&t.label&&s!==""?t.label:""},f=s=>{setTimeout(()=>{var e;return(e=document.getElementById(s))==null?void 0:e.focus()},100)};export{l as S,f,c as g,d as o};
