import{a0 as c,G as a,z as r,j as u,cF as i,cu as l,cG as m}from"./index-lOezWVmi.js";const j=({description:e,className:s})=>{const t=c(),{hasDocumentationObject:n}=a(),o=r({queryKey:["documentation/objects.inv.txt"],queryFn:async()=>m(n),staleTime:6e4});return e?u.jsx("span",{className:s,dangerouslySetInnerHTML:{__html:i(l(e),t,o.data)}}):null};export{j as C};
