import{A as i,j as n,R as s,cQ as x}from"./index-lOezWVmi.js";const g=({item:e,activeProject:a,type:o,to:r,projectLinkDetailPage:p="instances"})=>{var c;const l=o==="image",{data:j=[]}=i(a,l),t=j.find(d=>d.fingerprint===e.name),u=((c=t==null?void 0:t.properties)==null?void 0:c.description)||e.name;return n.jsxs("div",{children:[e.project!==a&&n.jsxs(n.Fragment,{children:[n.jsx(s,{type:"project",value:e.project,to:`/ui/project/${encodeURIComponent(e.project)}/${encodeURIComponent(p)}`})," ","/"," "]}),o==="snapshot"&&e.instance&&n.jsxs(n.Fragment,{children:[n.jsx(s,{type:"instance",value:e.instance,to:`/ui/project/${encodeURIComponent(e.project)}/instance/${encodeURIComponent(e.instance)}`})," ","/"," "]}),o==="snapshot"&&e.volume&&n.jsxs(n.Fragment,{children:[n.jsx(s,{type:"volume",value:e.volume,to:x({name:e.volume,project:e.project,pool:e.pool,type:"custom",location:e.target??""})})," ","/"," "]}),n.jsx(s,{type:o,value:u,to:r})]})};export{g as U};
