import{cT as x,E as S,cU as g,z as y,q as m,j as r,K as t,cV as j}from"./index-lOezWVmi.js";import{M as b}from"./Meter-CCMCY0F-.js";const C=({pool:e,hasMeterBar:u})=>{const{data:o=[]}=x(e.name),d=S(),a=g(e.driver)&&d,{data:l}=y({queryKey:[m.storage,e.name,m.resources],queryFn:async()=>j(e.name),enabled:!a}),f=a?o:[l];return!u&&a?"Cluster member dependent":r.jsx("div",{children:f.map(s=>{var i;if(!s)return r.jsx(r.Fragment,{children:(i=e.config)==null?void 0:i.size});const n=s.space.total,c=s.space.used||0;return u?r.jsx(b,{percentage:100/n*c||0,text:`${t(c)} of ${t(n)} used`},s.memberName):r.jsx("div",{children:`${t(c)} of ${t(n)} used`},s.memberName)})})};export{C as S};
