import{j as o}from"./index-lOezWVmi.js";const s=({children:t})=>o.jsx("div",{className:"p-bottom-controls form-footer",id:"form-footer",children:o.jsx("footer",{className:"u-align--right bottom-btns",children:t})});export{s as F};
