import{r,j as s,d as e}from"./index-lOezWVmi.js";const l=5,i=({items:t})=>{const[a,n]=r.useState(l);return s.jsxs(s.Fragment,{children:[t.slice(0,a),a<t.length&&s.jsx(e.Button,{appearance:"link",className:"u-no-margin--bottom",small:!0,onClick:o=>{n(t.length),o.stopPropagation()},children:"Show all"})]})};export{i as E};
