const n=(t,s,e)=>{const a=new URLSearchParams(s.toString());return e.forEach(r=>{a.delete(r),c(t,r).forEach(o=>{a.append(r,o)})}),a},c=(t,s)=>t.filter(e=>e.lead===s||s==="query"&&e.quoteValue).map(e=>e.value),h=(t,s)=>{const e=[];return s.forEach(a=>e.push(...t.getAll(a).map(r=>a==="query"?{quoteValue:!0,value:r}:{lead:a,value:r}))),e},u=(t,s)=>{let e=`${window.location.pathname}?search=${Number(t.get("search"))+1}`;const a=r=>{t.getAll(r).forEach(o=>e+=`&${r}=${o}`)};return s.forEach(a),e};export{h as a,n as p,u as s};
