import{j as n,d as s}from"./index-lOezWVmi.js";const o=({linkText:e,title:a,onClick:r})=>{const c=n.jsxs(n.Fragment,{children:[n.jsx(s.Icon,{name:"chevron-left"})," ",n.jsx(s.Button,{onClick:r,dense:!0,appearance:"link",className:"p-heading--4",children:e})]});return n.jsxs(n.Fragment,{children:[c," / ",a]})},i=({title:e,icon:a,onClick:r,subText:c,isModified:t})=>n.jsxs(s.Button,{appearance:"base",className:"form-link",onClick:r,type:"button",children:[n.jsxs("span",{className:"form-link__column",children:[n.jsx(s.Icon,{name:a,className:"form-link__icon"}),n.jsx("span",{className:"form-link__title",children:e})]}),n.jsxs("span",{className:"form-link__column u-align--right",children:[t&&n.jsx(s.Icon,{name:"status-in-progress-small"}),n.jsx("span",{className:"form-link__count u-text--muted",children:c}),n.jsx(s.Icon,{name:"chevron-right"})]})]});export{o as B,i as F};
