import{j as s,s as a}from"./index-lOezWVmi.js";const x=({percentage:i,secondaryPercentage:t=0,text:l,hoverText:m})=>s.jsxs(s.Fragment,{children:[s.jsxs("div",{className:"p-meter u-no-margin--bottom",title:m,children:[s.jsx("div",{style:{width:`max(${i}%, 5px)`},className:a({"has-next-sibling":t>0})}),t?s.jsx("div",{className:"has-previous-sibling",style:{width:`${t}%`}}):null]}),s.jsx("div",{className:"p-text--small u-no-margin--bottom u-text--muted",children:l})]});export{x as M};
