const i=t=>{var e;(e=document.getElementById(t))==null||e.scrollIntoView({inline:"nearest",block:"nearest"})},r=(t,e)=>{const l=e?e.scrollTop:0,c=e?e.offsetTop:0;let o=t[0];for(const n of t){const s=document.getElementById(n.toLowerCase());if(((s==null?void 0:s.offsetTop)??0)>l+c+25)return o;o=n}return o};export{r as g,i as s};
